==> libreoffice-still-sdk-6.3.5-1-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/search/enumvalues_f.js <==
var searchData=
[
  ['page_39759',['PAGE',['../namespacecom_1_1sun_1_1star_1_1form.html#acb5251eb1c7e6ff2149158596346de94ab788d9e2cde88d51a5cda409f75db490',1,'com::sun::star::form::PAGE()'],['../namespacecom_1_1sun_1_1star_1_1sheet.html#a686c797e7cb837947558aa11c946245aab788d9e2cde88d51a5cda409f75db490',1,'com::sun::star::sheet::PAGE()']]],
  ['page_5fafter_39760',['PAGE_AFTER',['../namespacecom_1_1sun_1_1star_1_1style.html#a3ae28cb49c180ec160a0984600b2b925a49bd5000d49e256cdd35e9d907e3a62d',1,'com::sun::star::style']]],
  ['page_5fbefore_39761',['PAGE_BEFORE',['../namespacecom_1_1sun_1_1star_1_1style.html#a3ae28cb49c180ec160a0984600b2b925a877534c01574cb50b4b8863741629326',1,'com::sun::star::style']]],
  ['page_5fboth_39762',['PAGE_BOTH',['../namespacecom_1_1sun_1_1star_1_1style.html#a3ae28cb49c180ec160a0984600b2b925a413421fe60ae31ccacb0db3758201d8d',1,'com::sun::star::style']]],
  ['page_5fend_39763',['PAGE_END',['../namespacecom_1_1sun_1_1star_1_1chart2.html#a85df18f245c9e4d24e32ebb9ee879042a82e429858e2344acb277006228f61455',1,'com::sun::star::chart2::PAGE_END()'],['../namespacecom_1_1sun_1_1star_1_1text.html#a95d9f731f1389ee9f277e756b476251ca82e429858e2344acb277006228f61455',1,'com::sun::star::text::PAGE_END()']]],
  ['page_5fstart_39764',['PAGE_START',['../namespacecom_1_1sun_1_1star_1_1chart2.html#a85df18f245c9e4d24e32ebb9ee879042a2fca4591070e35f79a40cd6b0b0205f3',1,'com::sun::star::chart2']]],
  ['paragraph_39765',['PARAGRAPH',['../namespacecom_1_1sun_1_1star_1_1smarttags.html#a2eab74f21d11f78b5aa7826b0c60604fa382476de0bc4f3380442b1ee05a9071c',1,'com::sun::star::smarttags']]],
  ['parallel_39766',['PARALLEL',['../namespacecom_1_1sun_1_1star_1_1drawing.html#ae1e109a5c70543e3b92db3b854fd3acba154165f3c0988bf0a9e9defb783b2171',1,'com::sun::star::drawing::PARALLEL()'],['../namespacecom_1_1sun_1_1star_1_1text.html#a1ed96de3f2d76e93588f67d506a0b0aea90606f8ca5d91452541a74f1caef1d11',1,'com::sun::star::text::PARALLEL()']]],
  ['parent_39767',['PARENT',['../namespacecom_1_1sun_1_1star_1_1form.html#ad79e40635743aa91020c7ddf34c3af31a283df3974c567b21c067198a24cd78e6',1,'com::sun::star::form']]],
  ['partially_5flocally_5fsent_39768',['PARTIALLY_LOCALLY_SENT',['../namespacecom_1_1sun_1_1star_1_1ucb.html#a8dec3ee1933cc93724b3764b124b8cc1a83428c380def50ca67756a102050c1a7',1,'com::sun::star::ucb']]],
  ['password_5fcreate_39769',['PASSWORD_CREATE',['../namespacecom_1_1sun_1_1star_1_1task.html#a921a6f0fb0abf824f006cab79dbc54d0a1d8d37a43bd4d76bf197cb14dc96605d',1,'com::sun::star::task']]],
  ['password_5fenter_39770',['PASSWORD_ENTER',['../namespacecom_1_1sun_1_1star_1_1task.html#a921a6f0fb0abf824f006cab79dbc54d0a558d4c0f391edf7290bd66a2261b79df',1,'com::sun::star::task']]],
  ['password_5freenter_39771',['PASSWORD_REENTER',['../namespacecom_1_1sun_1_1star_1_1task.html#a921a6f0fb0abf824f006cab79dbc54d0a9022d57993c505afcf6e8b3957ea3d7c',1,'com::sun::star::task']]],
  ['patch_39772',['PATCH',['../namespacecom_1_1sun_1_1star_1_1ucb.html#a3c143367536e0c519b25183505ae3ed7a8968cec66e1a913f0ef4d1205a7bf098',1,'com::sun::star::ucb']]],
  ['path_39773',['PATH',['../namespacecom_1_1sun_1_1star_1_1drawing.html#a0babaeb0d04df312f158184b26a302d6ad67a493278074cf714b262b33d84739c',1,'com::sun::star::drawing::PATH()'],['../namespacecom_1_1sun_1_1star_1_1presentation.html#a10f2a3114ab31c0e6f7dc48f656fd260ad67a493278074cf714b262b33d84739c',1,'com::sun::star::presentation::PATH()']]],
  ['pathfill_39774',['PATHFILL',['../namespacecom_1_1sun_1_1star_1_1drawing.html#adec70dcaa1fdfc08f03cf30ccee65ef6a663213fb9ecc9f835a997e42b9de9b6e',1,'com::sun::star::drawing']]],
  ['pathline_39775',['PATHLINE',['../namespacecom_1_1sun_1_1star_1_1drawing.html#adec70dcaa1fdfc08f03cf30ccee65ef6ab26989303571e39efe894611a7695390',1,'com::sun::star::drawing']]],
  ['pathplin_39776',['PATHPLIN',['../namespacecom_1_1sun_1_1star_1_1drawing.html#adec70dcaa1fdfc08f03cf30ccee65ef6a3bca1db3f7df1d850b7d3aea61301a69',1,'com::sun::star::drawing']]],
  ['pathpoly_39777',['PATHPOLY',['../namespacecom_1_1sun_1_1star_1_1drawing.html#adec70dcaa1fdfc08f03cf30ccee65ef6a0cd6b63d30c8c017bc6824d11ac6e226',1,'com::sun::star::drawing']]],
  ['pending_39778',['Pending',['../namespacecom_1_1sun_1_1star_1_1inspection.html#a2c7cbb6dbe76b989188c75ba8e400876a1f7a25007001fe77317521028b7af642',1,'com::sun::star::inspection::Pending()'],['../namespacecom_1_1sun_1_1star_1_1ucb.html#ab0378c2985abaca86838ed9936c3a2d5a1869818fd53ff519eb8e429301bdff73',1,'com::sun::star::ucb::PENDING()']]],
  ['percent_39779',['PERCENT',['../namespacecom_1_1sun_1_1star_1_1chart.html#a5dc5747cfef559a2185b3400717ee431a322ad1169a1de4a422a8447783954022',1,'com::sun::star::chart']]],
  ['percentage_39780',['PERCENTAGE',['../namespacecom_1_1sun_1_1star_1_1chart2.html#a364615e20b0759c6c5100f6a47add923aee7c061a4ea53ca0cd5717e800617b39',1,'com::sun::star::chart2']]],
  ['persistent_39781',['PERSISTENT',['../namespacecom_1_1sun_1_1star_1_1ucb.html#a7b9847f348fd7f6a0fc461f821c08173a9c9c5bc7490e9a68e4705e5fa413122f',1,'com::sun::star::ucb']]],
  ['perspective_39782',['PERSPECTIVE',['../namespacecom_1_1sun_1_1star_1_1drawing.html#a635428fef8d6e4afba288610c9c65bd5a2c5d7801888c03752f28943ac85d805f',1,'com::sun::star::drawing']]],
  ['phong_39783',['PHONG',['../namespacecom_1_1sun_1_1star_1_1drawing.html#af49ab4b65513d2c0077f76b2227326e9ab105fa30ed5e94117ebf6a37008f5e49',1,'com::sun::star::drawing']]],
  ['plin_39784',['PLIN',['../namespacecom_1_1sun_1_1star_1_1drawing.html#adec70dcaa1fdfc08f03cf30ccee65ef6a408176cf894ab276f3d7fc870065e90f',1,'com::sun::star::drawing']]],
  ['point_39785',['POINT',['../namespacecom_1_1sun_1_1star_1_1drawing.html#aac70ce37cdcc7a4bfcf79309db1a438ba15108ccafa3232b9067f889b6156f565',1,'com::sun::star::drawing']]],
  ['poly_39786',['POLY',['../namespacecom_1_1sun_1_1star_1_1drawing.html#adec70dcaa1fdfc08f03cf30ccee65ef6a7d85766d041d397d096dcbc0d7c793fd',1,'com::sun::star::drawing']]],
  ['polygon_39787',['POLYGON',['../namespacecom_1_1sun_1_1star_1_1chart2.html#a8068445d248b830d1708dcb2a2afb2c6ad5355465780b9a6259ebbc74d47477db',1,'com::sun::star::chart2']]],
  ['polynomial_39788',['POLYNOMIAL',['../namespacecom_1_1sun_1_1star_1_1chart.html#a00d1bb45d8b0a2aac5e07cde2f18302ba412e53300e8c1062adefbeb918f2e635',1,'com::sun::star::chart']]],
  ['pop3_39789',['POP3',['../namespacecom_1_1sun_1_1star_1_1mail.html#ad93fba9b1c1a9b0a2469f7c1fc392a06a986d5bdc5633cfa56007195f5619a496',1,'com::sun::star::mail']]],
  ['pop_5fdirectional_5fformat_39790',['POP_DIRECTIONAL_FORMAT',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a6e8fd3df14c13e43a44061c70daacd8ba0f396756541c8321e9e308ea9623cb24',1,'com::sun::star::i18n']]],
  ['portrait_39791',['PORTRAIT',['../namespacecom_1_1sun_1_1star_1_1view.html#a5312aa9f24f5483f2a37fd41a47d852aaf824fcbdaf7ede37030e39a2156f51e1',1,'com::sun::star::view']]],
  ['positive_39792',['POSITIVE',['../namespacecom_1_1sun_1_1star_1_1linguistic2.html#a281c5a7578308b66c77c9e0de51b806aa03d440bbbfb042afc85347f994b44fb5',1,'com::sun::star::linguistic2']]],
  ['post_39793',['POST',['../namespacecom_1_1sun_1_1star_1_1form.html#ae9bf553104504664f5d2066375a414dfa368c5bc07109370b819193871352b926',1,'com::sun::star::form::POST()'],['../namespacecom_1_1sun_1_1star_1_1ucb.html#a3c143367536e0c519b25183505ae3ed7a368c5bc07109370b819193871352b926',1,'com::sun::star::ucb::POST()']]],
  ['power_39794',['POWER',['../namespacecom_1_1sun_1_1star_1_1chart.html#a00d1bb45d8b0a2aac5e07cde2f18302ba316771101d4b4b1dea7d7e2a82ef1658',1,'com::sun::star::chart']]],
  ['presentationrange_5fall_39795',['PRESENTATIONRANGE_ALL',['../namespacecom_1_1sun_1_1star_1_1presentation.html#a69c71b14b95cc70bce7122a7b8287045ace36577428c938b50876bcae84be72b6',1,'com::sun::star::presentation']]],
  ['presentationrange_5ffrom_5fpage_39796',['PRESENTATIONRANGE_FROM_PAGE',['../namespacecom_1_1sun_1_1star_1_1presentation.html#a69c71b14b95cc70bce7122a7b8287045a1737f8348f8af8e0e913318467951124',1,'com::sun::star::presentation']]],
  ['presentationrange_5findividual_39797',['PRESENTATIONRANGE_INDIVIDUAL',['../namespacecom_1_1sun_1_1star_1_1presentation.html#a69c71b14b95cc70bce7122a7b8287045a15cfe5ff0a56692c532173e1499768e1',1,'com::sun::star::presentation']]],
  ['prev_39798',['PREV',['../namespacecom_1_1sun_1_1star_1_1text.html#aeffd73e249af906f303724f66f1f01c5ab359289a088e693e1c62099baf550b39',1,'com::sun::star::text']]],
  ['prevpage_39799',['PREVPAGE',['../namespacecom_1_1sun_1_1star_1_1presentation.html#a85fe75121d351785616b75b2c5661d8fa28d2ae2c68bb9aab9a4cc6b2acecc51e',1,'com::sun::star::presentation']]],
  ['processed_39800',['PROCESSED',['../namespacecom_1_1sun_1_1star_1_1ucb.html#a82ef3fdcd414866879e7aae1e52748d0a1fc33209ce8339be14a808bf6ceb9e52',1,'com::sun::star::ucb']]],
  ['processing_5finstruction_5fnode_39801',['PROCESSING_INSTRUCTION_NODE',['../namespacecom_1_1sun_1_1star_1_1xml_1_1dom.html#acac9cbaeea226ed297804c012dc12b16a8f02e3b5ecf06a0f46ba2fd1acf59598',1,'com::sun::star::xml::dom']]],
  ['product_39802',['PRODUCT',['../namespacecom_1_1sun_1_1star_1_1sheet.html#ad184d5bd9055f3b4fd57ce72c781758dacb6911398e0068f545a31b82bcdef3e4',1,'com::sun::star::sheet']]],
  ['program_39803',['PROGRAM',['../namespacecom_1_1sun_1_1star_1_1presentation.html#a85fe75121d351785616b75b2c5661d8fa76bedc8bb393f65efc8b19384a0a87e2',1,'com::sun::star::presentation']]],
  ['property_39804',['PROPERTY',['../namespacecom_1_1sun_1_1star_1_1script.html#a63e3de542c5d38de617ab78c8c8f5a41a96d4cdbfda7ac5f4dadee33f08ee7bd0',1,'com::sun::star::script::PROPERTY()'],['../namespacecom_1_1sun_1_1star_1_1uno.html#a00683ed3ec24b47c36ead10a20d6f328a96d4cdbfda7ac5f4dadee33f08ee7bd0',1,'com::sun::star::uno::PROPERTY()']]],
  ['propfind_39805',['PROPFIND',['../namespacecom_1_1sun_1_1star_1_1ucb.html#a3c143367536e0c519b25183505ae3ed7af0c35596861604f262d826937a54c82b',1,'com::sun::star::ucb']]],
  ['proportional_39806',['PROPORTIONAL',['../namespacecom_1_1sun_1_1star_1_1drawing.html#a119322ec5cab271556edacd80f9d780aad35adb33a4bd3162eff7f960ea0ad37a',1,'com::sun::star::drawing']]],
  ['proppatch_39807',['PROPPATCH',['../namespacecom_1_1sun_1_1star_1_1ucb.html#a3c143367536e0c519b25183505ae3ed7a1fcf4be2a7c47c519018d238039b8a5e',1,'com::sun::star::ucb']]],
  ['push_39808',['PUSH',['../namespacecom_1_1sun_1_1star_1_1form.html#abd774094fc2fbbdf91448f8a60c1798aad263caec619c4d99e4684ba0fabd9493',1,'com::sun::star::form']]],
  ['put_39809',['PUT',['../namespacecom_1_1sun_1_1star_1_1ucb.html#a3c143367536e0c519b25183505ae3ed7afec39d40e8bc9e12afa614df5ddb9fa9',1,'com::sun::star::ucb']]]
];

==> libreoffice-still-sdk-6.3.6-1-x86_64.pkg.tar.zst: usr/share/doc/libreoffice/sdk/docs/idl/ref/search/enumvalues_f.js <==
var searchData=
[
  ['page_39759',['PAGE',['../namespacecom_1_1sun_1_1star_1_1form.html#acb5251eb1c7e6ff2149158596346de94ab788d9e2cde88d51a5cda409f75db490',1,'com::sun::star::form::PAGE()'],['../namespacecom_1_1sun_1_1star_1_1sheet.html#a686c797e7cb837947558aa11c946245aab788d9e2cde88d51a5cda409f75db490',1,'com::sun::star::sheet::PAGE()']]],
  ['page_5fafter_39760',['PAGE_AFTER',['../namespacecom_1_1sun_1_1star_1_1style.html#a3ae28cb49c180ec160a0984600b2b925a49bd5000d49e256cdd35e9d907e3a62d',1,'com::sun::star::style']]],
  ['page_5fbefore_39761',['PAGE_BEFORE',['../namespacecom_1_1sun_1_1star_1_1style.html#a3ae28cb49c180ec160a0984600b2b925a877534c01574cb50b4b8863741629326',1,'com::sun::star::style']]],
  ['page_5fboth_39762',['PAGE_BOTH',['../namespacecom_1_1sun_1_1star_1_1style.html#a3ae28cb49c180ec160a0984600b2b925a413421fe60ae31ccacb0db3758201d8d',1,'com::sun::star::style']]],
  ['page_5fend_39763',['PAGE_END',['../namespacecom_1_1sun_1_1star_1_1chart2.html#a85df18f245c9e4d24e32ebb9ee879042a82e429858e2344acb277006228f61455',1,'com::sun::star::chart2::PAGE_END()'],['../namespacecom_1_1sun_1_1star_1_1text.html#a95d9f731f1389ee9f277e756b476251ca82e429858e2344acb277006228f61455',1,'com::sun::star::text::PAGE_END()']]],
  ['page_5fstart_39764',['PAGE_START',['../namespacecom_1_1sun_1_1star_1_1chart2.html#a85df18f245c9e4d24e32ebb9ee879042a2fca4591070e35f79a40cd6b0b0205f3',1,'com::sun::star::chart2']]],
  ['paragraph_39765',['PARAGRAPH',['../namespacecom_1_1sun_1_1star_1_1smarttags.html#a2eab74f21d11f78b5aa7826b0c60604fa382476de0bc4f3380442b1ee05a9071c',1,'com::sun::star::smarttags']]],
  ['parallel_39766',['PARALLEL',['../namespacecom_1_1sun_1_1star_1_1drawing.html#ae1e109a5c70543e3b92db3b854fd3acba154165f3c0988bf0a9e9defb783b2171',1,'com::sun::star::drawing::PARALLEL()'],['../namespacecom_1_1sun_1_1star_1_1text.html#a1ed96de3f2d76e93588f67d506a0b0aea90606f8ca5d91452541a74f1caef1d11',1,'com::sun::star::text::PARALLEL()']]],
  ['parent_39767',['PARENT',['../namespacecom_1_1sun_1_1star_1_1form.html#ad79e40635743aa91020c7ddf34c3af31a283df3974c567b21c067198a24cd78e6',1,'com::sun::star::form']]],
  ['partially_5flocally_5fsent_39768',['PARTIALLY_LOCALLY_SENT',['../namespacecom_1_1sun_1_1star_1_1ucb.html#a8dec3ee1933cc93724b3764b124b8cc1a83428c380def50ca67756a102050c1a7',1,'com::sun::star::ucb']]],
  ['password_5fcreate_39769',['PASSWORD_CREATE',['../namespacecom_1_1sun_1_1star_1_1task.html#a921a6f0fb0abf824f006cab79dbc54d0a1d8d37a43bd4d76bf197cb14dc96605d',1,'com::sun::star::task']]],
  ['password_5fenter_39770',['PASSWORD_ENTER',['../namespacecom_1_1sun_1_1star_1_1task.html#a921a6f0fb0abf824f006cab79dbc54d0a558d4c0f391edf7290bd66a2261b79df',1,'com::sun::star::task']]],
  ['password_5freenter_39771',['PASSWORD_REENTER',['../namespacecom_1_1sun_1_1star_1_1task.html#a921a6f0fb0abf824f006cab79dbc54d0a9022d57993c505afcf6e8b3957ea3d7c',1,'com::sun::star::task']]],
  ['patch_39772',['PATCH',['../namespacecom_1_1sun_1_1star_1_1ucb.html#a3c143367536e0c519b25183505ae3ed7a8968cec66e1a913f0ef4d1205a7bf098',1,'com::sun::star::ucb']]],
  ['path_39773',['PATH',['../namespacecom_1_1sun_1_1star_1_1drawing.html#a0babaeb0d04df312f158184b26a302d6ad67a493278074cf714b262b33d84739c',1,'com::sun::star::drawing::PATH()'],['../namespacecom_1_1sun_1_1star_1_1presentation.html#a10f2a3114ab31c0e6f7dc48f656fd260ad67a493278074cf714b262b33d84739c',1,'com::sun::star::presentation::PATH()']]],
  ['pathfill_39774',['PATHFILL',['../namespacecom_1_1sun_1_1star_1_1drawing.html#adec70dcaa1fdfc08f03cf30ccee65ef6a663213fb9ecc9f835a997e42b9de9b6e',1,'com::sun::star::drawing']]],
  ['pathline_39775',['PATHLINE',['../namespacecom_1_1sun_1_1star_1_1drawing.html#adec70dcaa1fdfc08f03cf30ccee65ef6ab26989303571e39efe894611a7695390',1,'com::sun::star::drawing']]],
  ['pathplin_39776',['PATHPLIN',['../namespacecom_1_1sun_1_1star_1_1drawing.html#adec70dcaa1fdfc08f03cf30ccee65ef6a3bca1db3f7df1d850b7d3aea61301a69',1,'com::sun::star::drawing']]],
  ['pathpoly_39777',['PATHPOLY',['../namespacecom_1_1sun_1_1star_1_1drawing.html#adec70dcaa1fdfc08f03cf30ccee65ef6a0cd6b63d30c8c017bc6824d11ac6e226',1,'com::sun::star::drawing']]],
  ['pending_39778',['PENDING',['../namespacecom_1_1sun_1_1star_1_1ucb.html#ab0378c2985abaca86838ed9936c3a2d5a1869818fd53ff519eb8e429301bdff73',1,'com::sun::star::ucb::PENDING()'],['../namespacecom_1_1sun_1_1star_1_1inspection.html#a2c7cbb6dbe76b989188c75ba8e400876a1f7a25007001fe77317521028b7af642',1,'com::sun::star::inspection::Pending()']]],
  ['percent_39779',['PERCENT',['../namespacecom_1_1sun_1_1star_1_1chart.html#a5dc5747cfef559a2185b3400717ee431a322ad1169a1de4a422a8447783954022',1,'com::sun::star::chart']]],
  ['percentage_39780',['PERCENTAGE',['../namespacecom_1_1sun_1_1star_1_1chart2.html#a364615e20b0759c6c5100f6a47add923aee7c061a4ea53ca0cd5717e800617b39',1,'com::sun::star::chart2']]],
  ['persistent_39781',['PERSISTENT',['../namespacecom_1_1sun_1_1star_1_1ucb.html#a7b9847f348fd7f6a0fc461f821c08173a9c9c5bc7490e9a68e4705e5fa413122f',1,'com::sun::star::ucb']]],
  ['perspective_39782',['PERSPECTIVE',['../namespacecom_1_1sun_1_1star_1_1drawing.html#a635428fef8d6e4afba288610c9c65bd5a2c5d7801888c03752f28943ac85d805f',1,'com::sun::star::drawing']]],
  ['phong_39783',['PHONG',['../namespacecom_1_1sun_1_1star_1_1drawing.html#af49ab4b65513d2c0077f76b2227326e9ab105fa30ed5e94117ebf6a37008f5e49',1,'com::sun::star::drawing']]],
  ['plin_39784',['PLIN',['../namespacecom_1_1sun_1_1star_1_1drawing.html#adec70dcaa1fdfc08f03cf30ccee65ef6a408176cf894ab276f3d7fc870065e90f',1,'com::sun::star::drawing']]],
  ['point_39785',['POINT',['../namespacecom_1_1sun_1_1star_1_1drawing.html#aac70ce37cdcc7a4bfcf79309db1a438ba15108ccafa3232b9067f889b6156f565',1,'com::sun::star::drawing']]],
  ['poly_39786',['POLY',['../namespacecom_1_1sun_1_1star_1_1drawing.html#adec70dcaa1fdfc08f03cf30ccee65ef6a7d85766d041d397d096dcbc0d7c793fd',1,'com::sun::star::drawing']]],
  ['polygon_39787',['POLYGON',['../namespacecom_1_1sun_1_1star_1_1chart2.html#a8068445d248b830d1708dcb2a2afb2c6ad5355465780b9a6259ebbc74d47477db',1,'com::sun::star::chart2']]],
  ['polynomial_39788',['POLYNOMIAL',['../namespacecom_1_1sun_1_1star_1_1chart.html#a00d1bb45d8b0a2aac5e07cde2f18302ba412e53300e8c1062adefbeb918f2e635',1,'com::sun::star::chart']]],
  ['pop3_39789',['POP3',['../namespacecom_1_1sun_1_1star_1_1mail.html#ad93fba9b1c1a9b0a2469f7c1fc392a06a986d5bdc5633cfa56007195f5619a496',1,'com::sun::star::mail']]],
  ['pop_5fdirectional_5fformat_39790',['POP_DIRECTIONAL_FORMAT',['../namespacecom_1_1sun_1_1star_1_1i18n.html#a6e8fd3df14c13e43a44061c70daacd8ba0f396756541c8321e9e308ea9623cb24',1,'com::sun::star::i18n']]],
  ['portrait_39791',['PORTRAIT',['../namespacecom_1_1sun_1_1star_1_1view.html#a5312aa9f24f5483f2a37fd41a47d852aaf824fcbdaf7ede37030e39a2156f51e1',1,'com::sun::star::view']]],
  ['positive_39792',['POSITIVE',['../namespacecom_1_1sun_1_1star_1_1linguistic2.html#a281c5a7578308b66c77c9e0de51b806aa03d440bbbfb042afc85347f994b44fb5',1,'com::sun::star::linguistic2']]],
  ['post_39793',['POST',['../namespacecom_1_1sun_1_1star_1_1form.html#ae9bf553104504664f5d2066375a414dfa368c5bc07109370b819193871352b926',1,'com::sun::star::form::POST()'],['../namespacecom_1_1sun_1_1star_1_1ucb.html#a3c143367536e0c519b25183505ae3ed7a368c5bc07109370b819193871352b926',1,'com::sun::star::ucb::POST()']]],
  ['power_39794',['POWER',['../namespacecom_1_1sun_1_1star_1_1chart.html#a00d1bb45d8b0a2aac5e07cde2f18302ba316771101d4b4b1dea7d7e2a82ef1658',1,'com::sun::star::chart']]],
  ['presentationrange_5fall_39795',['PRESENTATIONRANGE_ALL',['../namespacecom_1_1sun_1_1star_1_1presentation.html#a69c71b14b95cc70bce7122a7b8287045ace36577428c938b50876bcae84be72b6',1,'com::sun::star::presentation']]],
  ['presentationrange_5ffrom_5fpage_39796',['PRESENTATIONRANGE_FROM_PAGE',['../namespacecom_1_1sun_1_1star_1_1presentation.html#a69c71b14b95cc70bce7122a7b8287045a1737f8348f8af8e0e913318467951124',1,'com::sun::star::presentation']]],
  ['presentationrange_5findividual_39797',['PRESENTATIONRANGE_INDIVIDUAL',['../namespacecom_1_1sun_1_1star_1_1presentation.html#a69c71b14b95cc70bce7122a7b8287045a15cfe5ff0a56692c532173e1499768e1',1,'com::sun::star::presentation']]],
  ['prev_39798',['PREV',['../namespacecom_1_1sun_1_1star_1_1text.html#aeffd73e249af906f303724f66f1f01c5ab359289a088e693e1c62099baf550b39',1,'com::sun::star::text']]],
  ['prevpage_39799',['PREVPAGE',['../namespacecom_1_1sun_1_1star_1_1presentation.html#a85fe75121d351785616b75b2c5661d8fa28d2ae2c68bb9aab9a4cc6b2acecc51e',1,'com::sun::star::presentation']]],
  ['processed_39800',['PROCESSED',['../namespacecom_1_1sun_1_1star_1_1ucb.html#a82ef3fdcd414866879e7aae1e52748d0a1fc33209ce8339be14a808bf6ceb9e52',1,'com::sun::star::ucb']]],
  ['processing_5finstruction_5fnode_39801',['PROCESSING_INSTRUCTION_NODE',['../namespacecom_1_1sun_1_1star_1_1xml_1_1dom.html#acac9cbaeea226ed297804c012dc12b16a8f02e3b5ecf06a0f46ba2fd1acf59598',1,'com::sun::star::xml::dom']]],
  ['product_39802',['PRODUCT',['../namespacecom_1_1sun_1_1star_1_1sheet.html#ad184d5bd9055f3b4fd57ce72c781758dacb6911398e0068f545a31b82bcdef3e4',1,'com::sun::star::sheet']]],
  ['program_39803',['PROGRAM',['../namespacecom_1_1sun_1_1star_1_1presentation.html#a85fe75121d351785616b75b2c5661d8fa76bedc8bb393f65efc8b19384a0a87e2',1,'com::sun::star::presentation']]],
  ['property_39804',['PROPERTY',['../namespacecom_1_1sun_1_1star_1_1script.html#a63e3de542c5d38de617ab78c8c8f5a41a96d4cdbfda7ac5f4dadee33f08ee7bd0',1,'com::sun::star::script::PROPERTY()'],['../namespacecom_1_1sun_1_1star_1_1uno.html#a00683ed3ec24b47c36ead10a20d6f328a96d4cdbfda7ac5f4dadee33f08ee7bd0',1,'com::sun::star::uno::PROPERTY()']]],
  ['propfind_39805',['PROPFIND',['../namespacecom_1_1sun_1_1star_1_1ucb.html#a3c143367536e0c519b25183505ae3ed7af0c35596861604f262d826937a54c82b',1,'com::sun::star::ucb']]],
  ['proportional_39806',['PROPORTIONAL',['../namespacecom_1_1sun_1_1star_1_1drawing.html#a119322ec5cab271556edacd80f9d780aad35adb33a4bd3162eff7f960ea0ad37a',1,'com::sun::star::drawing']]],
  ['proppatch_39807',['PROPPATCH',['../namespacecom_1_1sun_1_1star_1_1ucb.html#a3c143367536e0c519b25183505ae3ed7a1fcf4be2a7c47c519018d238039b8a5e',1,'com::sun::star::ucb']]],
  ['push_39808',['PUSH',['../namespacecom_1_1sun_1_1star_1_1form.html#abd774094fc2fbbdf91448f8a60c1798aad263caec619c4d99e4684ba0fabd9493',1,'com::sun::star::form']]],
  ['put_39809',['PUT',['../namespacecom_1_1sun_1_1star_1_1ucb.html#a3c143367536e0c519b25183505ae3ed7afec39d40e8bc9e12afa614df5ddb9fa9',1,'com::sun::star::ucb']]]
];
